Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterServiceServer(s grpc.ServiceRegistrar, srv ServiceServer)
- type Config
- func (*Config) Descriptor() ([]byte, []int)deprecated
- func (x *Config) GetApplication() string
- func (x *Config) GetCommand() string
- func (x *Config) GetContinent() string
- func (x *Config) GetCountry() string
- func (x *Config) GetData() []byte
- func (x *Config) GetEnvironment() string
- func (x *Config) GetKind() string
- func (x *Config) GetVersion() string
- func (*Config) ProtoMessage()
- func (x *Config) ProtoReflect() protoreflect.Message
- func (x *Config) Reset()
- func (x *Config) String() string
- type GetConfigRequest
- func (*GetConfigRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetConfigRequest) GetApplication() string
- func (x *GetConfigRequest) GetCommand() string
- func (x *GetConfigRequest) GetContinent() string
- func (x *GetConfigRequest) GetCountry() string
- func (x *GetConfigRequest) GetEnvironment() string
- func (x *GetConfigRequest) GetKind() string
- func (x *GetConfigRequest) GetVersion() string
- func (*GetConfigRequest) ProtoMessage()
- func (x *GetConfigRequest) ProtoReflect() protoreflect.Message
- func (x *GetConfigRequest) Reset()
- func (x *GetConfigRequest) String() string
- type GetConfigResponse
- func (*GetConfigResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetConfigResponse) GetConfig() *Config
- func (x *GetConfigResponse) GetMeta() map[string]string
- func (*GetConfigResponse) ProtoMessage()
- func (x *GetConfigResponse) ProtoReflect() protoreflect.Message
- func (x *GetConfigResponse) Reset()
- func (x *GetConfigResponse) String() string
- type GetSecretsRequest
- func (*GetSecretsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetSecretsRequest) GetSecrets() map[string]string
- func (*GetSecretsRequest) ProtoMessage()
- func (x *GetSecretsRequest) ProtoReflect() protoreflect.Message
- func (x *GetSecretsRequest) Reset()
- func (x *GetSecretsRequest) String() string
- type GetSecretsResponse
- func (*GetSecretsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetSecretsResponse) GetMeta() map[string]string
- func (x *GetSecretsResponse) GetSecrets() map[string][]byte
- func (*GetSecretsResponse) ProtoMessage()
- func (x *GetSecretsResponse) ProtoReflect() protoreflect.Message
- func (x *GetSecretsResponse) Reset()
- func (x *GetSecretsResponse) String() string
- type ServiceClient
- type ServiceServer
- type UnimplementedServiceServer
- type UnsafeServiceServer
Constants ¶
const ( Service_GetConfig_FullMethodName = "/konfig.v1.Service/GetConfig" Service_GetSecrets_FullMethodName = "/konfig.v1.Service/GetSecrets" )
Variables ¶
var File_konfig_v1_service_proto protoreflect.FileDescriptor
var Service_ServiceDesc = grpc.ServiceDesc{ ServiceName: "konfig.v1.Service", HandlerType: (*ServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetConfig", Handler: _Service_GetConfig_Handler, }, { MethodName: "GetSecrets", Handler: _Service_GetSecrets_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "konfig/v1/service.proto", }
Service_ServiceDesc is the grpc.ServiceDesc for Service service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterServiceServer ¶ added in v1.14.0
func RegisterServiceServer(s grpc.ServiceRegistrar, srv ServiceServer)
Types ¶
type Config ¶ added in v1.14.0
type Config struct {
Application string `protobuf:"bytes,1,opt,name=application,proto3" json:"application,omitempty"`
Version string `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"`
Environment string `protobuf:"bytes,3,opt,name=environment,proto3" json:"environment,omitempty"`
Continent string `protobuf:"bytes,4,opt,name=continent,proto3" json:"continent,omitempty"`
Country string `protobuf:"bytes,5,opt,name=country,proto3" json:"country,omitempty"`
Command string `protobuf:"bytes,6,opt,name=command,proto3" json:"command,omitempty"`
Kind string `protobuf:"bytes,7,opt,name=kind,proto3" json:"kind,omitempty"`
Data []byte `protobuf:"bytes,8,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
Config for a specific application.
func (*Config) Descriptor
deprecated
added in
v1.14.0
func (*Config) GetApplication ¶ added in v1.14.0
func (*Config) GetCommand ¶ added in v1.14.0
func (*Config) GetContinent ¶ added in v1.24.0
func (*Config) GetCountry ¶ added in v1.25.0
func (*Config) GetEnvironment ¶ added in v1.14.0
func (*Config) GetVersion ¶ added in v1.14.0
func (*Config) ProtoMessage ¶ added in v1.14.0
func (*Config) ProtoMessage()
func (*Config) ProtoReflect ¶ added in v1.14.0
func (x *Config) ProtoReflect() protoreflect.Message
type GetConfigRequest ¶
type GetConfigRequest struct {
Application string `protobuf:"bytes,1,opt,name=application,proto3" json:"application,omitempty"`
Version string `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"`
Environment string `protobuf:"bytes,3,opt,name=environment,proto3" json:"environment,omitempty"`
Continent string `protobuf:"bytes,4,opt,name=continent,proto3" json:"continent,omitempty"`
Country string `protobuf:"bytes,5,opt,name=country,proto3" json:"country,omitempty"`
Command string `protobuf:"bytes,6,opt,name=command,proto3" json:"command,omitempty"`
Kind string `protobuf:"bytes,7,opt,name=kind,proto3" json:"kind,omitempty"`
// contains filtered or unexported fields
}
GetConfigRequest for a specific application.
func (*GetConfigRequest) Descriptor
deprecated
func (*GetConfigRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetConfigRequest.ProtoReflect.Descriptor instead.
func (*GetConfigRequest) GetApplication ¶
func (x *GetConfigRequest) GetApplication() string
func (*GetConfigRequest) GetCommand ¶
func (x *GetConfigRequest) GetCommand() string
func (*GetConfigRequest) GetContinent ¶ added in v1.24.0
func (x *GetConfigRequest) GetContinent() string
func (*GetConfigRequest) GetCountry ¶ added in v1.25.0
func (x *GetConfigRequest) GetCountry() string
func (*GetConfigRequest) GetEnvironment ¶
func (x *GetConfigRequest) GetEnvironment() string
func (*GetConfigRequest) GetKind ¶ added in v1.28.0
func (x *GetConfigRequest) GetKind() string
func (*GetConfigRequest) GetVersion ¶
func (x *GetConfigRequest) GetVersion() string
func (*GetConfigRequest) ProtoMessage ¶
func (*GetConfigRequest) ProtoMessage()
func (*GetConfigRequest) ProtoReflect ¶
func (x *GetConfigRequest) ProtoReflect() protoreflect.Message
func (*GetConfigRequest) Reset ¶
func (x *GetConfigRequest) Reset()
func (*GetConfigRequest) String ¶
func (x *GetConfigRequest) String() string
type GetConfigResponse ¶
type GetConfigResponse struct {
Meta map[string]string `` /* 149-byte string literal not displayed */
Config *Config `protobuf:"bytes,2,opt,name=config,proto3" json:"config,omitempty"`
// contains filtered or unexported fields
}
GetConfigResponse for a specific application.
func (*GetConfigResponse) Descriptor
deprecated
func (*GetConfigResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetConfigResponse.ProtoReflect.Descriptor instead.
func (*GetConfigResponse) GetConfig ¶ added in v1.14.0
func (x *GetConfigResponse) GetConfig() *Config
func (*GetConfigResponse) GetMeta ¶ added in v1.50.0
func (x *GetConfigResponse) GetMeta() map[string]string
func (*GetConfigResponse) ProtoMessage ¶
func (*GetConfigResponse) ProtoMessage()
func (*GetConfigResponse) ProtoReflect ¶
func (x *GetConfigResponse) ProtoReflect() protoreflect.Message
func (*GetConfigResponse) Reset ¶
func (x *GetConfigResponse) Reset()
func (*GetConfigResponse) String ¶
func (x *GetConfigResponse) String() string
type GetSecretsRequest ¶ added in v1.127.0
type GetSecretsRequest struct {
Secrets map[string]string `` /* 155-byte string literal not displayed */
// contains filtered or unexported fields
}
GetSecretsRequest a map of name and secret.
func (*GetSecretsRequest) Descriptor
deprecated
added in
v1.127.0
func (*GetSecretsRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetSecretsRequest.ProtoReflect.Descriptor instead.
func (*GetSecretsRequest) GetSecrets ¶ added in v1.127.0
func (x *GetSecretsRequest) GetSecrets() map[string]string
func (*GetSecretsRequest) ProtoMessage ¶ added in v1.127.0
func (*GetSecretsRequest) ProtoMessage()
func (*GetSecretsRequest) ProtoReflect ¶ added in v1.127.0
func (x *GetSecretsRequest) ProtoReflect() protoreflect.Message
func (*GetSecretsRequest) Reset ¶ added in v1.127.0
func (x *GetSecretsRequest) Reset()
func (*GetSecretsRequest) String ¶ added in v1.127.0
func (x *GetSecretsRequest) String() string
type GetSecretsResponse ¶ added in v1.127.0
type GetSecretsResponse struct {
Meta map[string]string `` /* 149-byte string literal not displayed */
Secrets map[string][]byte `` /* 155-byte string literal not displayed */
// contains filtered or unexported fields
}
GetSecretsResponse a map of meta and secrets.
func (*GetSecretsResponse) Descriptor
deprecated
added in
v1.127.0
func (*GetSecretsResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetSecretsResponse.ProtoReflect.Descriptor instead.
func (*GetSecretsResponse) GetMeta ¶ added in v1.127.0
func (x *GetSecretsResponse) GetMeta() map[string]string
func (*GetSecretsResponse) GetSecrets ¶ added in v1.127.0
func (x *GetSecretsResponse) GetSecrets() map[string][]byte
func (*GetSecretsResponse) ProtoMessage ¶ added in v1.127.0
func (*GetSecretsResponse) ProtoMessage()
func (*GetSecretsResponse) ProtoReflect ¶ added in v1.127.0
func (x *GetSecretsResponse) ProtoReflect() protoreflect.Message
func (*GetSecretsResponse) Reset ¶ added in v1.127.0
func (x *GetSecretsResponse) Reset()
func (*GetSecretsResponse) String ¶ added in v1.127.0
func (x *GetSecretsResponse) String() string
type ServiceClient ¶ added in v1.14.0
type ServiceClient interface {
// GetConfig for a specific application.
GetConfig(ctx context.Context, in *GetConfigRequest, opts ...grpc.CallOption) (*GetConfigResponse, error)
// GetSecrets that are configured.
GetSecrets(ctx context.Context, in *GetSecretsRequest, opts ...grpc.CallOption) (*GetSecretsResponse, error)
}
ServiceClient is the client API for Service service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Service allows to manage all application configurations.
func NewServiceClient ¶ added in v1.14.0
func NewServiceClient(cc grpc.ClientConnInterface) ServiceClient
type ServiceServer ¶ added in v1.14.0
type ServiceServer interface {
// GetConfig for a specific application.
GetConfig(context.Context, *GetConfigRequest) (*GetConfigResponse, error)
// GetSecrets that are configured.
GetSecrets(context.Context, *GetSecretsRequest) (*GetSecretsResponse, error)
// contains filtered or unexported methods
}
ServiceServer is the server API for Service service. All implementations must embed UnimplementedServiceServer for forward compatibility
Service allows to manage all application configurations.
type UnimplementedServiceServer ¶ added in v1.14.0
type UnimplementedServiceServer struct {
}
UnimplementedServiceServer must be embedded to have forward compatible implementations.
func (UnimplementedServiceServer) GetConfig ¶ added in v1.14.0
func (UnimplementedServiceServer) GetConfig(context.Context, *GetConfigRequest) (*GetConfigResponse, error)
func (UnimplementedServiceServer) GetSecrets ¶ added in v1.127.0
func (UnimplementedServiceServer) GetSecrets(context.Context, *GetSecretsRequest) (*GetSecretsResponse, error)
type UnsafeServiceServer ¶ added in v1.14.0
type UnsafeServiceServer interface {
// contains filtered or unexported methods
}
UnsafeServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ServiceServer will result in compilation errors.